@@ -46,7 +46,7 @@ use vars qw/@ISA @EXPORT @EXPORT_OK @EXPORT_TAGS
             $TIMEOUT @MODULES %MODULES %METHODS $AUTOLOAD
             @CURRENCY_RATES_MODULES $USE_EXPERIMENTAL_UA/;
 
-our $VERSION = '1.56_01'; # TRIAL VERSION
+our $VERSION = '1.56_02'; # TRIAL VERSION
 
 @CURRENCY_RATES_MODULES = qw/
     AlphaVantage
@@ -78,6 +78,7 @@ our $VERSION = '1.56_01'; # TRIAL VERSION
     Fool
     Fundata
     GoldMoney
+    GoogleWeb
     HU
     IEXCloud
     IndiaMutual
@@ -104,6 +105,7 @@ our $VERSION = '1.56_01'; # TRIAL VERSION
     Union
     XETRA
     YahooJSON
+    YahooWeb
     ZA
 /;
 
@@ -1687,6 +1689,7 @@ http://www.gnucash.org/
   Finance::Quote::Fool,
   Finance::Quote::Fundata
   Finance::Quote::GoldMoney,
+  Finance::Quote::GoogleWeb,
   Finance::Quote::HU,
   Finance::Quote::IEXCloud,
   Finance::Quote::IndiaMutual,
@@ -1709,6 +1712,7 @@ http://www.gnucash.org/
   Finance::Quote::TwelveData,
   Finance::Quote::Union,
   Finance::Quote::YahooJSON,
+  Finance::Quote::YahooWeb,
   Finance::Quote::ZA
 
 You should have received the Finance::Quote hacker's guide with this package.
